=begin

=bos_default

==description

BoS ɸץ饰
*ڡ/ʰWiki
*桼
*ץ饰

==class
*bos_pg.rb
*bos_plugin.rb
*bos_user.rb
*bos_prop.rb
*bos_miniwiki.rb
*bos_category.rb

==plugin
*bos_pg.rb
*bos_plugin.rb
*bos_user.rb
*bos_prop.rb
*bos_miniwiki.rb

==template
*product.htm

==admin_template
*index.htm
*admside.htm
*product.htm
*plugin.htm
*user.htm
*prop.htm

==admin_plugin
*bos_admin.rb

=end
